<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>过滤器:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>选择终端字体</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>字体:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>字体大小:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>&amp;Close Tab</source>
        <translation>关闭标签页(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>清空活动终端(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>&amp;Next Tab</source>
        <translation>下个标签页(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Keep window open when it loses focus</source>
        <translation>焦点失去时保持窗口开启</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>&amp;Previous Tab</source>
        <translation>最前终端页(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>&amp;Previous Tab in History</source>
        <translation>历史中的前一个选项卡(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>&amp;Next Tab in History</source>
        <translation>历史中的下一个选项卡(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Move Tab &amp;Left</source>
        <translation>往左边移动标签页(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Move Tab &amp;Right</source>
        <translation>往右边移动标签页(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Tab</source>
        <translation>标签</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Go to</source>
        <translation>前往</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Split &amp;View Top-Bottom</source>
        <translation>上下分屏查看</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Split Vie&amp;w Left-Right</source>
        <translation>左右分屏查看</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>&amp;Close Subterminal</source>
        <translation>关闭分屏</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>&amp;Top Subterminal</source>
        <translation>顶部分屏(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>底部分屏(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>L&amp;eft Subterminal</source>
        <translation>左部分屏(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>R&amp;ight Subterminal</source>
        <translation>右部分屏(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Copy &amp;Selection</source>
        <translation>复制选区(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>Paste S&amp;election</source>
        <translation>粘贴选区(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Handle history...</source>
        <translation>处理历史...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="354"/>
        <source>&amp;Save Session</source>
        <translation>保存会话(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;Load Session</source>
        <translation>载入会话(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Rename session</source>
        <translation>重命名会话</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>New Tab From &amp;Preset</source>
        <translation>新标签窗口(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>1 &amp;Terminal</source>
        <translation>单个终端窗口(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>水平分割为2(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>垂直分割为2(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>4 Terminal&amp;s</source>
        <translation>分割4块(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>&amp;Preferences...</source>
        <translation>参数配置(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Toggle Bookmarks</source>
        <translation>切换书签</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>&amp;Bottom</source>
        <translation>下(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>&amp;Top</source>
        <translation>上(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>&amp;Right</source>
        <translation>右(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>&amp;Left</source>
        <translation>左(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>&amp;Tabs Layout</source>
        <translation>标签位置(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>&amp;None</source>
        <translation>空(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>S&amp;crollbar Layout</source>
        <translation>滚动条位置(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>&amp;BlockCursor</source>
        <translation>块状光标(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>&amp;UnderlineCursor</source>
        <translation>下划线状光标(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>&amp;IBeamCursor</source>
        <translation>条状光标(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>光标样式(&amp;K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <source>A process is running.</source>
        <translation>进程运行中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Exit QTerminal</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="652"/>
        <source>Are you sure you want to exit?</source>
        <translation>您真的要关闭本程序吗?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>轻量级多平台支持的终端模拟器</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copyright (C) </source>
        <translation>版权 (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>2013-2025</source>
        <translation>2013-2025</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>LXQt Project</source>
        <translation>LXQt 项目</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Development: </source>
        <translation>开发： </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>按下&quot;%1&quot;显示该终端。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Paste Clip&amp;board</source>
        <translation>粘贴剪切板内容(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Zoom &amp;out</source>
        <translation>缩小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Zoom rese&amp;t</source>
        <translation>重置大小(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Find...</source>
        <translation>搜索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>&amp;Toggle Menu</source>
        <translation>下拉菜单(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Tab</source>
        <translation>新建标签页(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;New Window</source>
        <translation>新建窗口(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>&amp;Hide Window Borders</source>
        <translation>隐藏窗口边框(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Show Tab Bar</source>
        <translation>显示标签栏(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>Fullscreen</source>
        <translation>全屏显示</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="922"/>
        <source>Emulation</source>
        <translation>模拟器</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>终端设置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>界面设置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="38"/>
        <location filename="../forms/propertiesdialog.ui" line="729"/>
        <source>Behavior</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="56"/>
        <source>Dropdown</source>
        <translation>下拉菜单</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="181"/>
        <source>Color scheme</source>
        <translation>终端颜色</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Widget style</source>
        <translation>控件样式</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="207"/>
        <source>Scrollbar position</source>
        <translation>滚动栏位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>Tabs position</source>
        <translation>标签页位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="512"/>
        <source>Show the menu bar</source>
        <translation>显示菜单栏</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="287"/>
        <source>Terminal transparency</source>
        <translation>终端透明度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="370"/>
        <source>Start with preset:</source>
        <translation>默认配置:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>None (single terminal)</source>
        <translation>为空或者单终端模式</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="386"/>
        <source>2 terminals horizontally</source>
        <translation>水平分割为2块</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="391"/>
        <source>2 terminals vertically</source>
        <translation>垂直分割为2块</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="396"/>
        <source>4 terminals</source>
        <translation>４分割为4块</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="135"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="270"/>
        <source>Enable bi-directional text support</source>
        <translation>开启双目录文本支持</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="313"/>
        <source>Background image:</source>
        <translation>背景图像:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Select</source>
        <translation>选择</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="263"/>
        <source>Show terminal size on resize</source>
        <translation>重新调整大小时显示终端大小</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="414"/>
        <location filename="../forms/propertiesdialog.ui" line="573"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="536"/>
        <source>Show close button on each tab</source>
        <translation>在每个标签上显示关闭按钮</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Terminal margin</source>
        <translation>终端边距</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="280"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>使用字体中的方框绘制字符</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="519"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>使用 Alt 的快捷键可能会和终端应用程序互相干扰。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="522"/>
        <source>No menu bar accelerator</source>
        <translation>停用菜单栏快捷键</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Action after paste</source>
        <translation>粘贴之后的动作</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Confirm multiline paste</source>
        <translation>确认多行粘贴</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="835"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>修剪粘贴文本的最后空白行</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="849"/>
        <source>Open new terminals in current working directory</source>
        <translation>在当前工作路径打开新的终端</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="590"/>
        <source>Save Size when closing</source>
        <translation>关闭时保存窗口尺寸</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="583"/>
        <source>Save Position when closing</source>
        <translation>关闭时保存窗口位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Unlimited history</source>
        <translation>不限制历史记录条数</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="735"/>
        <source>History size (in lines)</source>
        <translation>历史记录大小 (行数)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <source>Default $TERM</source>
        <translation>默认 $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="609"/>
        <source>Start with this size:</source>
        <translation>启动时的终端大小：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="334"/>
        <source>Background mode:</source>
        <translation>后台模式：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="342"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Stretch</source>
        <translation>扩展</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="352"/>
        <source>Zoom</source>
        <translation>放大</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="357"/>
        <source>Fit</source>
        <translation>适合</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="362"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="277"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>指定应该由 QTerminal 绘制方框字符还是将其留给基础字体渲染库。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="253"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>切换是否为强调色使用粗体字</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="256"/>
        <source>Use bold font face for intense colors</source>
        <translation>为强调色使用粗体字</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="529"/>
        <source>&amp;Hide Window Borders</source>
        <translation>隐藏窗口边框(&amp;H)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;模仿哪个行为。请注意，这不必与您的操作系统匹配。&lt;/p&gt;&lt;p&gt;如果不确定，请使用
&lt;span style=&quot; font-weight:600;&quot;&gt;默认&lt;/span&gt; 模仿。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>此命令运行时将带有一个文件名作参数，它是一个含有回滚历史记录的临时文件</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="912"/>
        <source>Handle history command</source>
        <translation>处理历史命令</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="616"/>
        <location filename="../forms/propertiesdialog.ui" line="630"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Get current size</source>
        <translation>获取当前大小</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="859"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>在当前标签右侧打开新标签</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="856"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>如果未选中，新标签将在最右侧打开</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="546"/>
        <source>Close tab on middle-click</source>
        <translation>使用鼠标中键关闭标签</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="821"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>强制禁用方括号粘贴模式</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="775"/>
        <source>Word selection characters</source>
        <translation>选中字符识别为词语</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="246"/>
        <source>Blinking cursor</source>
        <translation>光标闪烁</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="421"/>
        <source>Current Terminal</source>
        <translation>当前终端</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Draw a border</source>
        <translation>绘制边框</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="434"/>
        <source>Set the current terminal on mouseover</source>
        <translation>鼠标悬停时设置为当前终端</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="441"/>
        <source>Change window title based on the terminal</source>
        <translation>根据终端更改窗口标题</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="448"/>
        <source>Change window icon based on the terminal</source>
        <translation>根据终端更改窗口图标</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="597"/>
        <source>Save State when closing</source>
        <translation>关闭时保存状态</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>当按单词选中时，将选中字符识别为单词的一部分，而不是单个字母数字字符</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="785"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="792"/>
        <source>Mouse cursor hiding delay</source>
        <translation>鼠标光标隐藏延时</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="799"/>
        <source>No hiding</source>
        <translation>不隐藏</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="818"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>括号粘贴模式对于粘贴多行字符串很有用。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="842"/>
        <source>Prompt on closing with a running process</source>
        <translation>提示关闭正在运行的进程</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="866"/>
        <source>Audible bell</source>
        <translation>听到铃声</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>如何编辑快捷方式：
1. 双击它的按键
2. 按下想要的组合键，然后松开
3. 点击一个快捷键或者按下回车

如果要删除或者禁用一个快捷键，在第 2 步只按下一个修饰键（比如 Shift）</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1009"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>锁定按钮显示在水平标签栏上</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1012"/>
        <source>Keep window open when it loses focus</source>
        <translation>窗口失去焦点时保持打开状态</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1030"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1040"/>
        <location filename="../forms/propertiesdialog.ui" line="1063"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1053"/>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1092"/>
        <source>Note: On Wayland, the shortcut has to be added in the compositor settings for &apos;qterminal -d&apos;.</source>
        <translation>注意：在 Wayland 上，必须在合成器设置中为 “qterminal -d ”添加快捷方式。</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1160"/>
        <source>Edit bookmark file contents</source>
        <translation>编辑书签文件内容</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1119"/>
        <source>Enable bookmarks</source>
        <translation>启用书签功能</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1128"/>
        <source>Bookmark file</source>
        <translation>书签文件</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="297"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="985"/>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="990"/>
        <source>Key</source>
        <translation>按键</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="65"/>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="556"/>
        <source>Hide tab bar with only one tab</source>
        <translation>只有一个页面时隐藏标签栏</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="171"/>
        <source>&amp;Change...</source>
        <translation>修改设置(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="233"/>
        <source>Cursor shape</source>
        <translation>光标形状</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="563"/>
        <source>Fixed tab width:</source>
        <translation>固定的选项卡宽度：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1002"/>
        <source>Show on start</source>
        <translation>启动时显示</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>Size</source>
        <translation>尺寸</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1083"/>
        <source>Shortcut:</source>
        <translation>快捷键:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1141"/>
        <source>Find...</source>
        <translation>搜索...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1150"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>您可以指定书签保存位置，它很容易通过私有云或者Dropbox分享。</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <source>No scrollbar</source>
        <translation>无滚动栏</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="167"/>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="173"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>BlockCursor</source>
        <translation>块状光标</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>UnderlineCursor</source>
        <translation>下划线状光标</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="186"/>
        <source>IBeamCursor</source>
        <translation>条状光标</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>No move</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to top</source>
        <translation>滚动到顶部</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="208"/>
        <source>Scrolling to bottom</source>
        <translation>滚动到底部</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="289"/>
        <source>Examples</source>
        <translation>Examples</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="456"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>图片 (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="558"/>
        <source>Open bookmarks file</source>
        <translation>打开书签文件</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="560"/>
        <source>XML files (*.xml)</source>
        <translation>XML files (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="561"/>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>Question</source>
        <translation>疑问</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="660"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>你想覆盖此书签文件吗？</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="664"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>书签文件的名称没有以&apos;.xml&apos;结尾。
你确定你要覆盖它吗？</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="672"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>无法将书签写入此文件:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="225"/>
        <location filename="../propertiesdialog.cpp" line="342"/>
        <source>System Default</source>
        <translation>系统默认</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="455"/>
        <source>Choose a background image</source>
        <translation>选择背景图片</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>书签同步</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="85"/>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Shell No. %1</source>
        <translation>Shell No. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Close Subterminal</source>
        <translation>关闭分屏</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="150"/>
        <source>Are you sure you want to close this subterminal?</source>
        <translation>你确定要关闭这个分屏吗？</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="222"/>
        <source>Tab name</source>
        <translation>标签名</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>New tab name:</source>
        <translation>新的标签名:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="243"/>
        <source>Select new tab title color</source>
        <translation>选择新的标签标题颜色</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="272"/>
        <source>Close session</source>
        <translation>关闭会话</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="274"/>
        <source>Change title color</source>
        <translation>更改标题颜色</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Close tab</source>
        <translation>关闭标签页</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="356"/>
        <source>Are you sure you want to close this tab?</source>
        <translation>你确定要关闭这个标签页吗？</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>载入会话</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>列出保存的会话:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="62"/>
        <source>&amp;Session</source>
        <translation>&amp;会话</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="70"/>
        <source>&amp;Actions</source>
        <translation>动作(&amp;A)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="75"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="87"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="103"/>
        <source>&amp;About...</source>
        <translation>关于本程序(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="108"/>
        <source>About &amp;Qt...</source>
        <translation>关于Qt(&amp;Q)...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>主窗口</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="82"/>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
</context>
</TS>
